@@ -6,9 +6,9 @@ use utf8;
 use Carp;
 ## no critic (RequireCarping)
 
-our $VERSION = 'v0.2.0';
+our $VERSION = 'v0.2.1';
 
-use List::Util qw( first any );
+use List::Util qw( first );
 use File::Temp qw( tempfile ); # don't use Path::Tiny to have temp files in error $SHELL
 
 use constant KW_DEFINE      => { map {$_=>1} qw( DEFINE DEFINE2 DEFINE4     ) };
@@ -449,7 +449,7 @@ App::migrate - upgrade / downgrade project
 
 =head1 VERSION
 
-This document describes App::migrate version v0.2.0
+This document describes App::migrate version v0.2.1
 
 
 =head1 SYNOPSIS
